==> hs-gtksourceview2-0.12.2_1.tbz: lib/ghc-7.0.3/cabal/gtksourceview2-0.12.2/register.sh <==
#!/bin/sh
echo 'name: gtksourceview2
version: 0.12.2
id: gtksourceview2-0.12.2-fe309edcee0c395e9e5ec75d25a4983f

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: GtkSourceView is a text widget that extends the standard GTK+ 2.x text widget
             GtkTextView. It improves GtkTextView by implementing syntax highlighting and
             other features typical of a source editor.
category: Graphics
author: Duncan Coutts, Peter Gavin, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.SourceView
                 Graphics.UI.Gtk.SourceView.Enums
                 Graphics.UI.Gtk.SourceView.SourceBuffer
                 Graphics.UI.Gtk.SourceView.SourceCompletion
                 Graphics.UI.Gtk.SourceView.SourceCompletionContext
                 Graphics.UI.Gtk.SourceView.SourceCompletionInfo
                 Graphics.UI.Gtk.SourceView.SourceCompletionItem
                 Graphics.UI.Gtk.SourceView.SourceCompletionProposal
                 Graphics.UI.Gtk.SourceView.SourceCompletionProvider
                 Graphics.UI.Gtk.SourceView.SourceGutter
                 Graphics.UI.Gtk.SourceView.SourceIter
                 Graphics.UI.Gtk.SourceView.SourceLanguage
                 Graphics.UI.Gtk.SourceView.SourceLanguageManager
                 Graphics.UI.Gtk.SourceView.SourceMark
                 Graphics.UI.Gtk.SourceView.SourceStyle
                 Graphics.UI.Gtk.SourceView.SourceStyleScheme
                 Graphics.UI.Gtk.SourceView.SourceStyleSchemeManager
                 Graphics.UI.Gtk.SourceView.SourceUndoManager
                 Graphics.UI.Gtk.SourceView.SourceView
hidden-modules: Graphics.UI.Gtk.SourceView.SourceStyle.Internal
                Graphics.UI.Gtk.SourceView.Types Graphics.UI.Gtk.SourceView.Signals
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/gtksourceview2-0.12.2
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/gtksourceview2-0.12.2
              /usr/local/lib
hs-libraries: HSgtksourceview2-0.12.2
extra-libraries: gtksourceview-2.0 gtk-x11-2.0 gdk-x11-2.0 atk-1.0
                 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite
                 Xdamage gdk_pixbuf-2.0 pangoft2-1.0 gio-2.0 Xfixes cairo X11
                 pango-1.0 m freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0
                 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/include/gtksourceview-2.0 /usr/local/include/libxml2
              /usr/local/include/gtk-2.0 /usr/local/lib/gtk-2.0/include
              /usr/local/include/atk-1.0 /usr/local/include/cairo
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/glib-2.0
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         glib-0.12.0-8144dd6b871a3f77547c0bef30f04b3e
         gtk-0.12.0-a4fda87069ff09531b8c7279ba868f94
         haskell98-1.1.0.1-b5235617d15eeebf246dacfc99755a36
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/gtksourceview2-0.12.2/html/gtksourceview2.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/gtksourceview2-0.12.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gtksourceview2-0.12.3.tbz: lib/ghc-7.0.4/cabal/gtksourceview2-0.12.3/register.sh <==
#!/bin/sh
echo 'name: gtksourceview2
version: 0.12.3
id: gtksourceview2-0.12.3-07d9115736676537bd742078919de52f

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: GtkSourceView is a text widget that extends the standard GTK+ 2.x text widget
             GtkTextView. It improves GtkTextView by implementing syntax highlighting and
             other features typical of a source editor.
category: Graphics
author: Duncan Coutts, Peter Gavin, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.SourceView
                 Graphics.UI.Gtk.SourceView.Enums
                 Graphics.UI.Gtk.SourceView.SourceBuffer
                 Graphics.UI.Gtk.SourceView.SourceCompletion
                 Graphics.UI.Gtk.SourceView.SourceCompletionContext
                 Graphics.UI.Gtk.SourceView.SourceCompletionInfo
                 Graphics.UI.Gtk.SourceView.SourceCompletionItem
                 Graphics.UI.Gtk.SourceView.SourceCompletionProposal
                 Graphics.UI.Gtk.SourceView.SourceCompletionProvider
                 Graphics.UI.Gtk.SourceView.SourceGutter
                 Graphics.UI.Gtk.SourceView.SourceIter
                 Graphics.UI.Gtk.SourceView.SourceLanguage
                 Graphics.UI.Gtk.SourceView.SourceLanguageManager
                 Graphics.UI.Gtk.SourceView.SourceMark
                 Graphics.UI.Gtk.SourceView.SourceStyle
                 Graphics.UI.Gtk.SourceView.SourceStyleScheme
                 Graphics.UI.Gtk.SourceView.SourceStyleSchemeManager
                 Graphics.UI.Gtk.SourceView.SourceUndoManager
                 Graphics.UI.Gtk.SourceView.SourceView
hidden-modules: Graphics.UI.Gtk.SourceView.SourceStyle.Internal
                Graphics.UI.Gtk.SourceView.Types Graphics.UI.Gtk.SourceView.Signals
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/gtksourceview2-0.12.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/gtksourceview2-0.12.3
              /usr/local/lib
hs-libraries: HSgtksourceview2-0.12.3
extra-libraries: gtksourceview-2.0 gtk-x11-2.0 gdk-x11-2.0 atk-1.0
                 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite
                 Xdamage gdk_pixbuf-2.0 pangoft2-1.0 gio-2.0 Xfixes cairo X11
                 pango-1.0 m freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0
                 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/include/gtksourceview-2.0 /usr/local/include/libxml2
              /usr/local/include/gtk-2.0 /usr/local/lib/gtk-2.0/include
              /usr/local/include/atk-1.0 /usr/local/include/cairo
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/glib-2.0
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         glib-0.12.2-14d626c7282f5f31da9b4a299a29106c
         gtk-0.12.2-eb6577e503c9105a0b596523a2dbc206
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/gtksourceview2-0.12.3/html/gtksourceview2.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/gtksourceview2-0.12.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
